@@ -1,6 +1,6 @@
 package Treex::Tool::Parser::MSTperl::Config;
 {
-  $Treex::Tool::Parser::MSTperl::Config::VERSION = '0.11336';
+  $Treex::Tool::Parser::MSTperl::Config::VERSION = '0.09407';
 }
 
 use Moose;
@@ -681,7 +681,7 @@ Treex::Tool::Parser::MSTperl::Config
 
 =head1 VERSION
 
-version 0.11336
+version 0.09407
 
 =head1 DESCRIPTION
 
@@ -996,9 +996,8 @@ training data, as it uses a lot of memory but speeds up the training greatly
 =item labeller_algorithm: 16
 
 Algorithm used for Viterbi labelling as well as for training. Several
-possibilities were tried out,
-especially regarding the emission probabilities used in the Viterbi algorithm;
-this is for development purposes only, preferebly do not use.
+possibilities are being tried out
+(especially regarding the emission probabilities used in the Viterbi algorithm).
 
 =over
 
